gchecky.model.alternate_tax_rule_t

Package gchecky :: Module model :: Class alternate_tax_rule_t |
[hide private]
[frames] | no frames]

# Class alternate_tax_rule_t

source code

    object --+
             |
     gxml.Node --+
                 |
        tax_rule_t --+
                     |
                    alternate_tax_rule_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
Inherited from `tax_rule_t`: `rate`, `tax_area`, `tax_areas` Inherited from `tax_rule_t` (private): `_fields`

Properties | [hide private]
Inherited from `object`: `__class__`